@@ -117,6 +117,8 @@ load_config (SeafileSession *session, const char *config_file_path)
     const char *private_key = NULL;
     const char *site_root = NULL;
     const char *log_to_stdout = NULL;
+    const char *node_name = NULL;
+    const char *use_go_fileserver = NULL;
 
     config = g_key_file_new ();
     if (!g_key_file_load_from_file (config, config_file_path,
@@ -144,6 +146,8 @@ load_config (SeafileSession *session, const char *config_file_path)
     log_to_stdout = g_getenv("SEAFILE_LOG_TO_STDOUT");
     notif_server = g_getenv("INNER_NOTIFICATION_SERVER_URL");
     enable_notif_server = g_getenv("ENABLE_NOTIFICATION_SERVER");
+    node_name = g_getenv("NODE_NAME");
+    use_go_fileserver = g_getenv("ENABLE_GO_FILESERVER");
 
     if (!private_key) {
         seaf_warning ("Failed to read JWT_PRIVATE_KEY.\n");
@@ -166,6 +170,15 @@ load_config (SeafileSession *session, const char *config_file_path)
         session->log_to_stdout = TRUE;
     }
 
+    if (!node_name || g_strcmp0 (node_name, "") == 0) {
+        node_name = "default";
+    }
+    session->node_name = g_strdup (node_name);
+
+    if (use_go_fileserver && g_strcmp0 (use_go_fileserver, "true") == 0) {
+        session->go_fileserver = TRUE; 
+    }
+
 out:
     if (ret < 0) {
         if (config)
